import os
import re
import tempfile
import uuid
from pathlib import Path


class PathUtil:
    """路径工具类"""

    @staticmethod
    def path(*paths):
        """
        构建路径
        :param paths: 路径组件
        :return: 完整路径
        """
        # 连接路径组件
        path = "/".join(paths)

        # 处理特殊前缀
        if path.startswith('project:'):
            path = path.replace("project:", PathUtil.project_path(), 1)
        elif path.startswith('goutool:'):
            path = path.replace("goutool:", PathUtil.goutool_path(), 1)
        elif path.startswith('gou2tool:'):
            path = path.replace("gou2tool:", PathUtil.goutool_path(), 1)
        elif path.startswith('system-temp:'):
            path = path.replace("system-temp:", tempfile.gettempdir(), 1)
        elif path.startswith('create-system-temp:'):
            temp_dir = tempfile.gettempdir()
            filename = path.replace("create-system-temp:", "")
            path = os.path.join(temp_dir, filename)
        elif path.startswith('create-system-temp-file:*'):
            temp_dir = tempfile.gettempdir()
            if path.startswith('create-system-temp-file:*.*'):
                ext = path.replace("create-system-temp-file:*.*", ".", 1)
            elif path.startswith('create-system-temp-file:*'):
                ext = ".tmp"
            else:
                ext = ""
            filename = str(uuid.uuid4()) + ext
            path = os.path.join(temp_dir, filename)
        elif path.startswith('vendor:'):
            path = path.replace("vendor:", os.path.join(PathUtil.project_path(), "vendor"), 1)

        # 规范化路径分隔符
        lists = [part for part in re.split(r'([/\\]+)', path) if part]

        # Linux环境下处理包含空格的路径
        if os.name != 'nt':  # 非Windows系统
            parts = re.split(r'([\\/]+)', path)
            for i, part in enumerate(parts):
                if re.search(r'\s', part) and not (part.startswith('"') and part.endswith('"')):
                    parts[i] = f'"{part}"'
            path = "".join(parts)

        return "".join(lists)

    @staticmethod
    def raw_path(path):
        """
        获取原始路径（去除引号）
        :param path: 路径
        :return: 原始路径
        """
        return path.replace('"', '')

    @staticmethod
    def exist(path):
        """
        检查文件或目录是否存在
        :param path: 路径
        :return: 是否存在
        """
        return os.path.exists(path)

    @staticmethod
    def is_path(path):
        """
        判断是否是有效路径格式
        :param path: 路径
        :return: 是否是路径
        """
        pattern = r'^(?:\/{2})?[a-zA-Z0-9._-]+(?:\/[a-zA-Z0-9._-]+)*$'
        return bool(re.match(pattern, path))

    @staticmethod
    def project_path():
        """
        获取应用根目录
        :return: 项目路径
        """
        # 这里需要根据实际项目结构调整
        current_dir = os.path.dirname(os.path.abspath(__file__))
        project = os.path.dirname(current_dir)  # 根据实际情况调整层级

        project_file = os.path.join(project, "composer.json")
        project_vendor = os.path.join(project, "vendor")
        goutool_file = os.path.join(project, "vendor", "wl4837", "goutool", "composer.json")

        if (os.path.exists(project_file) and os.path.isfile(project_file) and
                os.path.exists(project_vendor) and os.path.isdir(project_vendor) and
                os.path.exists(goutool_file) and os.path.isfile(goutool_file)):
            return project
        else:
            return PathUtil.goutool_path()

    @staticmethod
    def goutool_path():
        """
        获取框架目录
        :return: 框架路径
        """
        path = PathUtil.parent(os.path.abspath(__file__), 6)
        file_path = os.path.join(path, "setup.py")
        if os.path.exists(file_path) and os.path.isfile(file_path):
            return path
        return False

    @staticmethod
    def project_composer_path():
        """
        获取项目composer.json路径
        :return: composer.json路径
        """
        project_path = PathUtil.project_path()
        if project_path is False:
            return False
        file_path = os.path.join(project_path, "composer.json")
        if os.path.exists(file_path) and os.path.isfile(file_path):
            return file_path
        else:
            return False

    @staticmethod
    def project_package_path():
        """
        获取项目package.json路径
        :return: package.json路径
        """
        project_path = PathUtil.project_path()
        if project_path is False:
            return False
        file_path = os.path.join(project_path, "package.json")
        if os.path.exists(file_path) and os.path.isfile(file_path):
            return file_path
        else:
            return False

    @staticmethod
    def project_env_path():
        """
        获取项目.env文件路径
        :return: .env文件路径
        """
        project_path = PathUtil.project_path()
        if project_path is False:
            return False
        file_path = os.path.join(project_path, ".env")
        if os.path.exists(file_path) and os.path.isfile(file_path):
            return file_path
        else:
            return False

    @staticmethod
    def goutool_composer_path():
        """
        获取框架composer.json路径
        :return: composer.json路径
        """
        goutool_path = PathUtil.goutool_path()
        if goutool_path is False:
            return False
        file_path = os.path.join(goutool_path, "composer.json")
        if os.path.exists(file_path) and os.path.isfile(file_path):
            return file_path
        else:
            return False

    @staticmethod
    def name(path):
        """
        获取路径名称
        :param path: 路径
        :return: 路径名称
        """
        path = PathUtil.path(path)
        return os.path.basename(path)

    @staticmethod
    def parent(path, level=1):
        """
        获取上级路径
        :param path: 路径
        :param level: 上级层数
        :return: 上级路径
        """
        path = PathUtil.path(path)
        # 根据level层数逐级获取上级目录
        for _ in range(level):
            path = os.path.dirname(path)
        return path



import configparser
from pathlib import Path


class EnvUtil:

    @staticmethod
    def get(name, default=None, group='DEFAULT', env_file_path=None):
        config = configparser.ConfigParser()

        with open(env_file_path, 'r', encoding='utf-8') as f:
            content = f.read()

        if not content.strip().startswith('['):
            content = '[DEFAULT]\n' + content

        config.read_string(content)

        return config.get(group, name, fallback=default)



import unittest

from src.main.py.gou2tool.util.PathUtil import PathUtil

class TestDemo(unittest.TestCase):
    def test_simple_uuid(self):
        print(PathUtil.goutool_path())
        self.assertTrue(True)

if __name__ == '__main__':
    unittest.main()


import re

class DBTemplateUtil:

    @staticmethod
    def query_for_one(sql, params=None, connection=None):
        """
        执行SQL查询并返回单个结果的字典格式

        Args:
            sql (str): SQL查询语句
            connection: 数据库连接对象
            params (tuple|dict|None): SQL参数，支持元组或字典格式

        Returns:
            dict|None: 查询结果的字典表示，如果没有结果则返回None
        """
        cursor = connection.cursor()
        try:
            if params:
                cursor.execute(sql, params)
            else:
                cursor.execute(sql)
            result = cursor.fetchone()

            if result:
                # 获取列名
                columns = [column[0] for column in cursor.description]
                # 转换为字典格式
                return dict(zip(columns, result))
            return None
        except Exception as e:
            print(f"查询执行出错: {e}")
            return None
        finally:
            cursor.close()

    @staticmethod
    def query_for_list(sql, params=None, connection=None):
        """
        执行SQL查询并返回所有结果的字典列表格式

        Args:
            sql (str): SQL查询语句
            params (tuple|dict|None): SQL参数，支持元组或字典格式
            connection: 数据库连接对象

        Returns:
            list: 查询结果的字典列表，每个元素是一行数据的字典表示
        """
        cursor = connection.cursor()
        try:
            if params:
                cursor.execute(sql, params)
            else:
                cursor.execute(sql)
            results = cursor.fetchall()

            if results:
                # 获取列名
                columns = [column[0] for column in cursor.description]
                # 转换为字典列表格式
                return [dict(zip(columns, row)) for row in results]
            return []
        except Exception as e:
            print(f"查询执行出错: {e}")
            return []
        finally:
            cursor.close()

    @staticmethod
    def execute(sql, params=None, connection=None):
        """
        执行单条SQL增删改操作

        Args:
            sql (str): SQL语句
            params (tuple|dict|None): SQL参数，支持元组或字典格式
            connection: 数据库连接对象

        Returns:
            int: 受影响的行数
        """
        cursor = connection.cursor()
        try:
            if params:
                cursor.execute(sql, params)
            else:
                cursor.execute(sql)

            # 提交事务
            connection.commit()
            # 返回受影响的行数
            return cursor.rowcount
        except Exception as e:
            # 发生异常时回滚事务
            connection.rollback()
            print(f"执行出错: {e}")
            return 0
        finally:
            cursor.close()

    @staticmethod
    def execute_batch(sql, params_list=None, connection=None):
        """
        批量执行SQL增删改操作

        Args:
            sql (str): SQL语句模板
            params_list (list): 参数列表，每个元素是tuple或dict格式的参数
            connection: 数据库连接对象

        Returns:
            int: 受影响的行数总计
        """
        cursor = connection.cursor()
        try:
            if params_list:
                # 批量执行带参数的SQL语句
                cursor.executemany(sql, params_list)
            else:
                # 单次执行不带参数的SQL语句
                cursor.execute(sql)

            # 提交事务
            connection.commit()
            # 返回受影响的行数
            return cursor.rowcount
        except Exception as e:
            # 发生异常时回滚事务
            connection.rollback()
            print(f"批量执行出错: {e}")
            return 0
        finally:
            cursor.close()



import os
import json

class AddressUtil:

    @staticmethod
    def parse(address):
        """
        解析地址字符串，返回结构化地址信息

        Args:
            address (str): 完整地址字符串

        Returns:
            dict: 包含省、市、区等信息的字典
        """
        if not address:
            return {}

        # 初始化结果字典
        result = {
            "province": "",
            "city": "",
            "district": "",
            "street": "",
            "detail": ""
        }

        # 获取省市区数据用于匹配
        province_city_data = AddressUtil.get_province_city_district_tree()

        # 简化的地址解析逻辑（实际应用中可能需要更复杂的匹配规则）
        # 1. 提取省份信息
        for province_data in province_city_data:
            province_name = province_data.get("province", "")
            if province_name and province_name in address:
                result["province"] = province_name
                # 从地址中移除已匹配的省份信息
                address = address.replace(province_name, "", 1)
                break

        # 2. 提取城市信息
        for province_data in province_city_data:
            if "children" in province_data:
                for city_data in province_data["children"]:
                    city_name = city_data.get("city", "")
                    if city_name and city_name in address:
                        result["city"] = city_name
                        # 从地址中移除已匹配的城市信息
                        address = address.replace(city_name, "", 1)
                        break

        # 3. 提取区域信息
        for province_data in province_city_data:
            if "children" in province_data:
                for city_data in province_data["children"]:
                    if "children" in city_data:
                        for district_data in city_data["children"]:
                            district_name = district_data.get("district", "")
                            if district_name and district_name in address:
                                result["district"] = district_name
                                # 从地址中移除已匹配的区域信息
                                address = address.replace(district_name, "", 1)
                                break

        # 4. 剩余部分作为街道和详细地址
        result["street"] = address.strip()
        result["detail"] = address.strip()

        return result


    @staticmethod
    def has_province_city_district():
        """
        判断地址是否包含省市区信息

        Returns:
            bool: 如果包含省市区信息返回True，否则返回False
        """
        # TODO: 实现判断逻辑
        return False


    @staticmethod
    def has_province_city():
        """
        判断地址是否包含省市信息

        Returns:
            bool: 如果包含省市信息返回True，否则返回False
        """
        # TODO: 实现判断逻辑
        return False


    @staticmethod
    def get_province_city_district_tree():
        """
        获取省市区三级树形结构数据

        Returns:
            list: 省市区树形结构数据
        """
        # TODO: 实现获取省市区树形结构的逻辑
        # 获取当前脚本所在目录
        current_dir = os.path.dirname(__file__)
        # 构建数据文件路径
        data_file_path = os.path.join(current_dir, 'data', 'pca-code.json')

        # 读取JSON文件
        with open(data_file_path, 'r', encoding='utf-8') as file:
            data = json.load(file)

        return data


    @staticmethod
    def get_province_city_district_street_tree():
        """
        获取省市区街道四级树形结构数据

        Returns:
            list: 省市区街道树形结构数据
        """
        # TODO: 实现获取省市区街道树形结构的逻辑
        # 获取当前脚本所在目录
        current_dir = os.path.dirname(__file__)
        # 构建数据文件路径
        data_file_path = os.path.join(current_dir, 'data', 'pcas-code.json')

        # 读取JSON文件
        with open(data_file_path, 'r', encoding='utf-8') as file:
            data = json.load(file)

        return data
